==> qlcplus_4.12.2.orig.tar.xz: qlcplus-QLC-_4.12.2/plugins/osc/OSC_ja_JP.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>ConfigureOSC</name>
    <message>
        <location filename="configureosc.ui" line="33"/>
        <source>OSC Plugin Configuration</source>
        <oldsource>Configure OSC Plugin</oldsource>
        <translation type="unfinished">OSCプラグイン設定</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="47"/>
        <source>Universes Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="60"/>
        <source>Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="65"/>
        <source>Universe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="70"/>
        <source>Input Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="75"/>
        <source>Output Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="80"/>
        <source>Output Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="80"/>
        <source>Inputs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="86"/>
        <source>Outputs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="168"/>
        <source>Invalid IP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="168"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OSCPlugin</name>
    <message>
        <location filename="oscplugin.cpp" line="85"/>
        <source>This plugin provides input for devices supporting the OSC transmission protocol.</source>
        <translation type="unfinished">このプラグインはOSCを使ったMIDI信号の送受信を行います。(TouchOSCなど)</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="136"/>
        <location filename="oscplugin.cpp" line="270"/>
        <source>Status: Not open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="139"/>
        <location filename="oscplugin.cpp" line="273"/>
        <source>Status: Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="141"/>
        <source>Packets sent: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="275"/>
        <source>Packets received: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="132"/>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="266"/>
        <source>Input</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qlcplus_4.12.6.orig.tar.xz: qlcplus-QLC-_4.12.6/plugins/osc/OSC_ja_JP.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>ConfigureOSC</name>
    <message>
        <location filename="configureosc.ui" line="33"/>
        <source>OSC Plugin Configuration</source>
        <oldsource>Configure OSC Plugin</oldsource>
        <translation type="unfinished">OSCプラグイン設定</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="47"/>
        <source>Universes Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="60"/>
        <source>Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="65"/>
        <source>Universe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="70"/>
        <source>Input Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="75"/>
        <source>Output Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="80"/>
        <source>Output Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="88"/>
        <source>Channel number calculator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="96"/>
        <source>OSC path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="106"/>
        <source>Channel number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="83"/>
        <source>Inputs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="89"/>
        <source>Outputs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="171"/>
        <source>Invalid IP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="171"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OSCPlugin</name>
    <message>
        <location filename="oscplugin.cpp" line="91"/>
        <source>This plugin provides input for devices supporting the OSC transmission protocol.</source>
        <translation type="unfinished">このプラグインはOSCを使ったMIDI信号の送受信を行います。(TouchOSCなど)</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="142"/>
        <location filename="oscplugin.cpp" line="276"/>
        <source>Status: Not open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="145"/>
        <location filename="oscplugin.cpp" line="279"/>
        <source>Status: Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="147"/>
        <source>Packets sent: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="281"/>
        <source>Packets received: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="138"/>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="272"/>
        <source>Input</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
